@@ -46,7 +46,7 @@ def decompose_sales(df):
         forecast_reduced = forecast.loc[:, ['ds', 'yearly', 'weekly']]
         forecast_reduced['dow'] = forecast_reduced.ds.dt.weekday
         forecast_reduced['doy'] = forecast_reduced.ds.dt.dayofyear
-        forecast_reduced['woy'] = forecast_reduced.ds.dt.weekofyear
+        forecast_reduced['woy'] = forecast_reduced.ds.dt.week  # deprecated?
         week_trend = forecast_reduced.groupby('dow')['weekly'].mean() + 1
         forecast_reduced = forecast_reduced.iloc[-366:]
         forecast_reduced.sort_values(by=['woy', 'dow'], inplace=True)
